# Orchest SDK for Python

[Website](https://www.orchest.io) —
[Docs](https://docs.orchest.io/en/stable/fundamentals/sdk/index.html)

---

Python package for interacting with [Orchest](https://github.com/orchest/orchest).

## Installation

> **NOTE**: The Orchest SDK comes pre-installed in Orchest.

```sh
pip install orchest
```

## Next steps

Check out our
[quickstart](https://docs.orchest.io/en/stable/fundamentals/sdk/index.html#python) to get
started!

## Compatibility

> We started maintaining this table since Orchest release
> [`v2021.05.1`](https://github.com/orchest/orchest/releases/tag/v2021.05.1).

| Python SDK version | Orchest version | Compatible? |
| ------------------ | --------------- | ----------- |
| `>= v0.2.0`        | `>= v2021.05.1` | yes         |
